exceptiontools.NonbinaryTimeSignatureConversionError
====================================================

.. inheritance-diagram:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.NonbinaryTimeSignatureConversionError.NonbinaryTimeSignatureConversionError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
